==> codeready-workspaces-2.8.0-GA-crwctl-sources.tar.gz: crwctl/lib/commands/auth/get.js <==
"use strict";
/*********************************************************************
 * Copyright (c) 2020 Red Hat, Inc.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 **********************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const cli_ux_1 = require("cli-ux");
const che_login_manager_1 = require("../../api/che-login-manager");
const context_1 = require("../../api/context");
const common_flags_1 = require("../../common-flags");
const constants_1 = require("../../constants");
class Get extends command_1.Command {
    run() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { flags } = this.parse(Get);
            yield context_1.ChectlContext.init(flags, this);
            yield this.config.runHook(constants_1.DEFAULT_ANALYTIC_HOOK_NAME, { command: Get.id, flags });
            const loginManager = yield che_login_manager_1.CheServerLoginManager.getInstance();
            const currentLogin = loginManager.getCurrentLoginInfo();
            if (currentLogin.username) {
                cli_ux_1.cli.info(`Logged into ${currentLogin.cheApiEndpoint} as ${currentLogin.username}`);
            }
            else {
                cli_ux_1.cli.info('There is no active login session');
            }
        });
    }
}
exports.default = Get;
Get.description = 'Display active login session';
Get.flags = {
    help: command_1.flags.help({ char: 'h' }),
    telemetry: common_flags_1.CHE_TELEMETRY
};
//# sourceMappingURL=get.js.map

==> codeready-workspaces-2.12.0-GA-crwctl-sources.tar.gz: crwctl/lib/commands/auth/get.js <==
"use strict";
/**
 * Copyright (c) 2019-2021 Red Hat, Inc.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Red Hat, Inc. - initial API and implementation
 */
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const cli_ux_1 = require("cli-ux");
const che_login_manager_1 = require("../../api/che-login-manager");
const context_1 = require("../../api/context");
const common_flags_1 = require("../../common-flags");
const constants_1 = require("../../constants");
class Get extends command_1.Command {
    run() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { flags } = this.parse(Get);
            yield context_1.ChectlContext.init(flags, this);
            yield this.config.runHook(constants_1.DEFAULT_ANALYTIC_HOOK_NAME, { command: Get.id, flags });
            const loginManager = yield che_login_manager_1.CheServerLoginManager.getInstance();
            const currentLogin = loginManager.getCurrentLoginInfo();
            if (currentLogin.username) {
                cli_ux_1.cli.info(`Logged into ${currentLogin.cheApiEndpoint} as ${currentLogin.username}`);
            }
            else {
                cli_ux_1.cli.info('There is no active login session');
            }
        });
    }
}
exports.default = Get;
Get.description = 'Display active login session';
Get.flags = {
    help: command_1.flags.help({ char: 'h' }),
    telemetry: common_flags_1.CHE_TELEMETRY,
};
//# sourceMappingURL=get.js.map
